15.55. cdist-type__install_bootloader_grub(7) — cdist 4.10.4 documentation

# 15.55. cdist-type__install_bootloader_grub(7)

## 15.55.1. NAME

cdist-type__install_bootloader_grub - install grub2 bootloader on given disk

## 15.55.2. DESCRIPTION

This cdist type allows you to install grub2 bootloader on given disk.

## 15.55.3. REQUIRED PARAMETERS

None

## 15.55.4. OPTIONAL PARAMETERS

device
  The device to install grub to. Defaults to object_id
chroot
  where to chroot before running grub-install. Defaults to /target.

## 15.55.5. EXAMPLES

    __install_bootloader_grub /dev/sda

    __install_bootloader_grub /dev/sda --chroot /mnt/foobar

## 15.55.6. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 15.55.7. COPYING

Copyright (C) 2011 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.